summaryrefslogtreecommitdiffstats
path: root/chrome/test/perf
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/test/perf')
-rw-r--r--chrome/test/perf/rendering/latency_tests.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/test/perf/rendering/latency_tests.cc b/chrome/test/perf/rendering/latency_tests.cc
index fdd00d7..af3c761 100644
--- a/chrome/test/perf/rendering/latency_tests.cc
+++ b/chrome/test/perf/rendering/latency_tests.cc
@@ -99,9 +99,9 @@ const int kInputsPerFrame = 16;
const int kClearColorGreen = 137;
const int kMouseY = 5;
// Don't analyze begin frames that may be inaccurate. Latencies can be as high
// as 5 frames or so, so skip the first 6 frames to get more accurate results.
-const int kIgnoreBeginFrames = 6;
+const int kIgnoreStartFrames = 6;
// Don't analyze end frames that may be inaccurate.
const int kIgnoreEndFrames = 4;
// Minimum frames to produce an answer.
@@ -478,7 +478,7 @@ double LatencyTest::CalculateLatency() {
++swap_count;
// Don't analyze first few swaps, because they are filling the rendering
// pipeline and may be unstable.
- if (swap_count > kIgnoreBeginFrames) {
+ if (swap_count > kIgnoreStartFrames) {
// First, find the beginning of this swap.
size_t begin_swap_pos = 0;
EXPECT_TRUE(FindLastOf(events, query_begin_swaps_, end_swap_pos,
@@ -99,9 +99,9 @@ const int kInputsPerFrame = 16;
const int kClearColorGreen = 137;
const int kMouseY = 5;
-// Don't analyze begin frames that may be inaccurate. Latencies can be as high
+// Don't analyze start frames that may be inaccurate. Latencies can be as high
// as 5 frames or so, so skip the first 6 frames to get more accurate results.